@@ -150,6 +150,45 @@ class SourceImagesSelectorIconView(gtk.IconView):
     def clear(self):
         self.get_model().clear()
 
+    def _getIndexFromOffset(self, offset):
+        selected_items = self.get_selected_items()
+        if not len(selected_items):
+            return
+        selected_item_path = selected_items[0]
+        model = self.get_model()
+        iter = model.get_iter(selected_item_path)
+        index = model.get_path(iter)[0] + offset
+        number_of_items = model.iter_n_children(None)
+        if index < 0:
+            index = number_of_items + offset
+        elif index == number_of_items:
+            index = 0
+        return index
+
+    def movePage(self, offset):
+        selected_items = self.get_selected_items()
+        if not len(selected_items):
+            return
+        selected_item_path = selected_items[0]
+        model = self.get_model()
+        index = self._getIndexFromOffset(offset)
+        if index != selected_item_path[0] + offset:
+            return
+        model.swap(model.get_iter((index,)),
+                   model.get_iter(selected_item_path))
+        self.select_path((index,))
+
+    def selectPageFromOffset(self, offset):
+        selected_items = self.get_selected_items()
+        if not len(selected_items):
+            return
+        selected_item_path = selected_items[0]
+        model = self.get_model()
+        index = self._getIndexFromOffset(offset)
+        self.select_path((index,))
+
+    def getNumberOfPages(self):
+        return self.get_model().iter_n_children(None)
 
 class ImageReviewer(gtk.HPaned):
 
@@ -294,10 +333,13 @@ class ImageReviewer(gtk.HPaned):
 
     def getTextFromBoxes(self, boxes):
         text = ''
+        #@todo: Implement a proper way to get the boxes
+        # in reading order
         boxes.reverse()
         self.editor.saveDataBox()
         if boxes:
-            text = getTextFromBoxes([self.boxes_dict.get(box) for box in boxes])
+            text = self.page.getTextFromBoxes(
+                [self.boxes_dict.get(box) for box in boxes])
         else:
             if self.editor.box_editor.getType() == TEXT_TYPE:
                 text = self.box_editor.getText()
@@ -505,7 +547,6 @@ class ImageReviewer_Controler:
         self.__setZoomStatus(None, reviewer.selectable_boxes_area.get_scale())
         self.__updateStatusBar(reviewer)
         reviewer.updateMainWindow()
-        self.main_window.setHasImages(bool(reviewer))
 
     def __setZoomStatus(self, widget, zoom):
         self.__updateStatusBar()
@@ -660,52 +701,57 @@ class ImageReviewer_Controler:
         document_generator.addPage(page_data)
         document_generator.save()
 
-    def exportPagesToHtml(self, pixbufs_sorted = []):
-        pages = self.__askForNumberOfPages(_('Export to HTML'), pixbufs_sorted)
+    def exportPagesWithGenerator(self, generator, format_name):
+        extra_args = {}
+        if format_name == 'PDF':
+            from_scratch, cancelled = self.__askPdfFromScratch()
+            if cancelled:
+                return
+            extra_args['from_scratch'] = from_scratch
+
+        pages = self.__askForNumberOfPages(_('Export to %(format_name)s') %
+                                           {'format_name': format_name})
         if not pages:
             return
         file_name = self.__askForFileName()
         if file_name:
             if os.path.exists(file_name):
                 os.remove(file_name)
-            document_generator = HtmlGenerator(file_name)
+            document_generator = generator(file_name, **extra_args)
             for page in pages:
                 document_generator.addPage(page)
             document_generator.save()
 
+    def __askPdfFromScratch(self):
+        ask_pdf_type_dialog = gtk.MessageDialog(self.main_window.window,
+                      gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
+                      buttons = gtk.BUTTONS_OK_CANCEL)
+        ask_pdf_type_dialog.set_markup(_('What kind of PDF document do you '
+                                         'wish?'))
+        pdf_from_scratch_radio = gtk.RadioButton(label= _('From scratch'))
+        pdf_from_scratch_radio.set_tooltip_text(
+                                    _('Creates a new PDF from scratch.'))
+        searchable_pdf_radio = gtk.RadioButton(pdf_from_scratch_radio,
+                                               _('Searchable PDF'))
+        searchable_pdf_radio.set_tooltip_text(_('Creates a PDF based on '
+                                                'the images but with searchable '
+                                                'text.'))
+        vbox = gtk.VBox(True)
+        vbox.add(pdf_from_scratch_radio)
+        vbox.add(searchable_pdf_radio)
+        content_area = ask_pdf_type_dialog.get_content_area()
+        content_area.add(vbox)
+        content_area.show_all()
 
-    def exportPagesToOdt(self, pixbufs_sorted = []):
-        pages = self.__askForNumberOfPages(_('Export to ODT'), pixbufs_sorted)
-        if not pages:
-            return
-        file_name = self.__askForFileName()
-        if file_name:
-            document_generator = OdtGenerator(file_name)
-            for page in pages:
-                document_generator.addPage(page)
-            document_generator.save()
+        response = ask_pdf_type_dialog.run()
+        ask_pdf_type_dialog.destroy()
+        if response == gtk.RESPONSE_CANCEL:
+            return (False, True)
 
-    def exportPagesToPlaintext(self, pixbufs_sorted = []):
-        pages = self.__askForNumberOfPages(_('Export to Plain Text'), pixbufs_sorted)
-        if not pages:
-            return
-        file_name = self.__askForFileName()
-        if file_name:
-            document_generator = PlaintextGenerator(file_name)
-            for page in pages:
-                document_generator.addText(getTextFromBoxes(page.data_boxes))
-            document_generator.save()
-
-    def exportPagesToPdf(self, pixbufs_sorted = [], pdf_from_scratch = True):
-        pages = self.__askForNumberOfPages(_('Export to PDF'), pixbufs_sorted)
-        if not pages:
-            return
-        file_name = self.__askForFileName()
-        if file_name:
-            document_generator = PdfGenerator(file_name, pdf_from_scratch)
-            for page in pages:
-                document_generator.addPage(page)
-            document_generator.save()
+        pdf_from_scratch = True
+        if searchable_pdf_radio.get_active():
+            pdf_from_scratch = False
+        return (pdf_from_scratch, False)
 
     def saveProjectAs(self):
         return self.__askForFileName(extension = '.ocrf')
@@ -735,7 +781,7 @@ class ImageReviewer_Controler:
         open_dialog.destroy()
         return project_file
 
-    def __askForNumberOfPages(self, title, pixbufs_sorted):
+    def __askForNumberOfPages(self, title):
         # Sync the current reviewer's page with its data
         self.__getCurrentReviewer().savePageData()
         export_dialog = PagesToExportDialog(title)
@@ -1110,17 +1156,3 @@ class Editor:
         else:
             self.reviewer.main_window.copy_to_clipboard_menu.set_sensitive(True)
             self.reviewer.main_window.spellchecker_menu.set_sensitive(True)
-
-
-# Helper function to get text from data boxes
-def getTextFromBoxes(data_boxes):
-    text = ''
-    number_of_boxes = len(data_boxes)
-    for i in range(number_of_boxes):
-        data_box = data_boxes[i]
-        if data_box and data_box.getType() != TEXT_TYPE:
-            continue
-        text += data_box.getText()
-        if number_of_boxes > 1 and i < number_of_boxes - 1:
-            text += '\n\n'
-    return text
