@@ -45,76 +45,6 @@ _ = gettext.gettext
 
 class MainWindow:
 
-    menubar = '''<ui>
-    <menubar name="MenuBar">
-        <menu action="File">
-            <menuitem action="OpenProject"/>
-            <menuitem action="SaveProject"/>
-            <menuitem action="SaveProjectAs"/>
-            <separator/>
-            <menuitem action="AppendProject"/>
-            <separator/>
-            <menuitem action="AddImage"/>
-            <menuitem action="AddFolder"/>
-            <separator/>
-            <menuitem action="ImportPDF"/>
-            <separator/>
-            <menuitem action="ImportFromScanner"/>
-            <menuitem action="Export"/>
-            <separator/>
-            <menuitem action="Quit"/>
-        </menu>
-        <menu action="Edit">
-            <menuitem action="CopyToClipboard"/>
-            <separator/>
-            <menuitem action="EditPage"/>
-            <menuitem action="DeletePage"/>
-            <separator/>
-            <menuitem action="ClearProject"/>
-            <separator/>
-            <menuitem action="Preferences"/>
-        </menu>
-        <menu action="View">
-            <menuitem action="ZoomIn"/>
-            <menuitem action="ZoomOut"/>
-            <menuitem action="ResetZoom"/>
-            <menuitem action="ZoomFit"/>
-        </menu>
-        <menu action="Document">
-            <menuitem action="OCRFeederReconDocument"/>
-            <menuitem action="OCRFeederReconPage"/>
-            <menuitem action="RecognizeAreas"/>
-            <separator/>
-            <menuitem action="SelectAllAreas"/>
-            <menuitem action="SelectPreviousArea"/>
-            <menuitem action="SelectNextArea"/>
-            <separator/>
-            <menuitem action="DeleteSelectedAreas"/>
-        </menu>
-        <menu action="Tools">
-            <menuitem action="OCREngines"/>
-            <separator/>
-            <menuitem action="Unpaper"/>
-            <menuitem action="ImageDeskewer"/>
-            <separator/>
-            <menuitem action="SpellChecker"/>
-        </menu>
-        <menu action="Help">
-            <menuitem action="HelpContents"/>
-            <menuitem action="About"/>
-        </menu>
-    </menubar>
-    <toolbar name="ToolBar">
-        <toolitem action="AddImage"/>
-        <separator/>
-        <toolitem action="OCRFeederReconDocument"/>
-        <toolitem action="GenerateODT"/>
-        <separator/>
-        <toolitem action="ZoomOut"/>
-        <toolitem action="ZoomIn"/>
-    </toolbar>
-    </ui>'''
-
     def __init__(self):
         self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
         self.window.set_size_request(800, 600)
@@ -168,6 +98,10 @@ class MainWindow:
                                   ('EditPage', gtk.STOCK_EDIT, _('_Edit Page'), None, _('Edit page settings'), menu_items['edit_page']),
                                   ('Preferences', gtk.STOCK_PREFERENCES, _('_Preferences'), None, _('Configure the application'), menu_items['preferences']),
                                   ('DeletePage', gtk.STOCK_DELETE, _('_Delete Page'), None, _('Delete current page'), menu_items['delete_page']),
+                                  ('MovePageDown', gtk.STOCK_GO_DOWN, _('Move Page Do_wn'), '<control><shift>Page_Down', _('Move page down'), menu_items['move_page_down']),
+                                  ('MovePageUp', gtk.STOCK_GO_UP, _('Move Page Up'), '<control><shift>Page_Up', _('Move page up'), menu_items['move_page_up']),
+                                  ('SelectNextPage', gtk.STOCK_GO_DOWN, _('Select Next Page'), '<control>Page_Down', _('Select next page'), menu_items['select_next_page']),
+                                  ('SelectPreviousPage', gtk.STOCK_GO_UP, _('Select Previous Page'), '<control>Page_Up', _('Select previous page'), menu_items['select_previous_page']),
                                   ('ClearProject', gtk.STOCK_DELETE, _('_Clear Project'), None, _('Delete all images'), menu_items['clear']),
                                   ('View', None, _('_View')),
                                   ('ZoomIn', gtk.STOCK_ZOOM_IN, _('Zoom In'), '<control>plus', _("Zoom In"), menu_items['zoom_in']),
@@ -230,7 +164,7 @@ class MainWindow:
                                    menu_items['spell_checker']),
                                   ])
         ui_manager.insert_action_group(action_group, 0)
-        ui_manager.add_ui_from_string(self.menubar)
+        ui_manager.add_ui_from_file(OCRFEEDER_MENUBAR_UI)
         menu_bar = ui_manager.get_widget('/MenuBar/')
         self.main_box.pack_start(menu_bar, False)
         tool_bar = ui_manager.get_widget('/ToolBar')
@@ -259,7 +193,7 @@ class MainWindow:
     def setDestroyEvent(self, function):
         self.window.connect('delete-event', function)
 
-    def setHasImages(self, has_images = True):
+    def setNumberOfPages(self, nr_images):
         if not self.action_group:
             return
         actions = ['ZoomIn', 'ZoomOut', 'ResetZoom',
@@ -267,10 +201,15 @@ class MainWindow:
                    'DeletePage', 'SaveProject', 'SaveProjectAs',
                    'OCRFeederReconDocument', 'EditPage', 'ClearProject',
                    'AppendProject', 'ZoomFit', 'ImageDeskewer']
-        self.__setActionsSensitiveness(actions, has_images)
-        if not has_images:
+        self.__setActionsSensitiveness(actions, nr_images > 0)
+        if nr_images:
             self.setHasSelectedBoxes(False)
             self.setHasContentBoxes(False)
+        self.__setActionsSensitiveness(['SelectNextPage',
+                                        'SelectPreviousPage',
+                                        'MovePageUp',
+                                        'MovePageDown'],
+                                        nr_images > 1)
 
     def setHasSelectedBoxes(self, has_selected_boxes = True):
         if not self.action_group:
