@@ -24,7 +24,7 @@ import locale
 
 OCRFEEDER_STUDIO_NAME = 'OCRFeeder'
 OCRFEEDER_COMPACT_NAME = 'ocrfeeder'
-OCRFEEDER_STUDIO_VERSION = '0.7.9'
+OCRFEEDER_STUDIO_VERSION = '0.7.10'
 OCRFEEDER_STUDIO_AUTHORS = ['Joaquim Rocha <joaquimrocha1@gmail.com>']
 OCRFEEDER_STUDIO_ARTISTS = ['Joaquim Rocha <joaquimrocha1@gmail.com>']
 OCRFEEDER_COPYRIGHT = 'Copyright © 2008-2011 Joaquim Rocha\n' \
@@ -87,6 +87,7 @@ GHOSTSCRIPT_COMMAND = 'gs'
 
 # DeskTop Publishing Point (for calculating print measures)
 DTP = 72
-# location of glade spellchecker UI file
 
+# UI files' location
 OCRFEEDER_SPELLCHECKER_UI = os.path.join(RESOURCES_DIR, 'spell-checker.ui')
+OCRFEEDER_MENUBAR_UI = os.path.join(RESOURCES_DIR, 'menubar.ui')
